Calculate predicted values for given values of the reference-method.
MCResultResampling.calcResponse(
.Object,
x.levels,
alpha = 0.05,
bootcimeth = .Object@bootcimeth
)object of class 'MCResultResampling'
numeric vector specifying values of the reference method for which prediction should be made
significance level for confidence intervals
bootstrap confidence interval method to be used